@@ -1,4 +1,4 @@
-package Email::MIME::Kit::Renderer::TestRenderer 3.000007;
+package Email::MIME::Kit::Renderer::TestRenderer 3.000008;
 # ABSTRACT:  extremely simple renderer for testing purposes only
 
 use v5.20.0;
@@ -71,7 +71,7 @@ Email::MIME::Kit::Renderer::TestRenderer - extremely simple renderer for testing
 
 =head1 VERSION
 
-version 3.000007
+version 3.000008
 
 =head1 DESCRIPTION
 
@@ -101,13 +101,13 @@ example, this will actually get the OS:
 
 =head1 PERL VERSION
 
-This library should run on perls released even a long time ago.  It should work
-on any version of perl released in the last five years.
+This library should run on perls released even a long time ago.  It should
+work on any version of perl released in the last five years.
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
-for any reason, and there is no promise that patches will be accepted to lower
-the minimum required perl.
+for any reason, and there is no promise that patches will be accepted to
+lower the minimum required perl.
 
 =head1 WARNING
 
@@ -117,7 +117,7 @@ upset by something horrible soon.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
