@@ -1,4 +1,4 @@
-package Email::MIME::Kit::Role::KitReader 3.000007;
+package Email::MIME::Kit::Role::KitReader 3.000008;
 # ABSTRACT: things that can read kit contents
 
 use v5.20.0;
@@ -46,17 +46,17 @@ Email::MIME::Kit::Role::KitReader - things that can read kit contents
 
 =head1 VERSION
 
-version 3.000007
+version 3.000008
 
 =head1 PERL VERSION
 
-This library should run on perls released even a long time ago.  It should work
-on any version of perl released in the last five years.
+This library should run on perls released even a long time ago.  It should
+work on any version of perl released in the last five years.
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
-for any reason, and there is no promise that patches will be accepted to lower
-the minimum required perl.
+for any reason, and there is no promise that patches will be accepted to
+lower the minimum required perl.
 
 =head1 IMPLEMENTING
 
@@ -73,7 +73,7 @@ and will decode it to text before returning.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
