@@ -1,4 +1,4 @@
-package Email::MIME::Kit::Role::ManifestDesugarer 3.000007;
+package Email::MIME::Kit::Role::ManifestDesugarer 3.000008;
 # ABSTRACT: helper for desugaring manifests
 
 use v5.20.0;
@@ -75,17 +75,17 @@ Email::MIME::Kit::Role::ManifestDesugarer - helper for desugaring manifests
 
 =head1 VERSION
 
-version 3.000007
+version 3.000008
 
 =head1 PERL VERSION
 
-This library should run on perls released even a long time ago.  It should work
-on any version of perl released in the last five years.
+This library should run on perls released even a long time ago.  It should
+work on any version of perl released in the last five years.
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
-for any reason, and there is no promise that patches will be accepted to lower
-the minimum required perl.
+for any reason, and there is no promise that patches will be accepted to
+lower the minimum required perl.
 
 =head1 IMPLEMENTING
 
@@ -115,7 +115,7 @@ More behavior may be added to the desugarer later.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
